@@ -70,9 +70,9 @@ class MetricClientTest(base.ClientTestBase):
         self.assertEqual('None', metric["resource/id"])
         self.assertIn("metric-test", metric["archive_policy/name"])
 
-        # CREATE WITHOUT NAME AND WITH UNIT
+        # CREATE WITH UNIT
         result = self.gnocchi(
-            u'metric', params=u"create"
+            u'metric', params=u"create another-name"
             u" --archive-policy-name metric-test"
             u" --unit some-unit")
         metric = self.details_multiple(result)[0]
@@ -80,7 +80,7 @@ class MetricClientTest(base.ClientTestBase):
         self.assertEqual(self.clients.project_id,
                          metric["created_by_project_id"])
         self.assertEqual(self.clients.user_id, metric["created_by_user_id"])
-        self.assertEqual('None', metric["name"])
+        self.assertEqual('another-name', metric["name"])
         self.assertEqual('some-unit', metric["unit"])
         self.assertEqual('None', metric["resource/id"])
         self.assertIn("metric-test", metric["archive_policy/name"])
@@ -98,6 +98,22 @@ class MetricClientTest(base.ClientTestBase):
                                       ) % metric["id"])
         self.assertEqual("", result)
 
+        # MEASURES GET with refresh
+        result = self.gnocchi('measures',
+                              params=("show %s "
+                                      "--aggregation mean "
+                                      "--granularity 1 "
+                                      "--start 2015-03-06T14:32:00 "
+                                      "--stop 2015-03-06T14:36:00 "
+                                      "--refresh") % metric["id"])
+        measures = self.parser.listing(result)
+        self.assertEqual([{'granularity': '1.0',
+                           'timestamp': '2015-03-06T14:33:57+00:00',
+                           'value': '43.11'},
+                          {'granularity': '1.0',
+                           'timestamp': '2015-03-06T14:34:12+00:00',
+                           'value': '12.0'}], measures)
+
         # MEASURES GET
         result = self.retry_gnocchi(
             5, 'measures', params=("show %s "
@@ -114,11 +130,26 @@ class MetricClientTest(base.ClientTestBase):
                            'timestamp': '2015-03-06T14:34:12+00:00',
                            'value': '12.0'}], measures)
 
+        # MEASURES GET RESAMPLE
+        result = self.retry_gnocchi(
+            5, 'measures', params=("show %s "
+                                   "--aggregation mean "
+                                   "--granularity 1 --resample 3600 "
+                                   "--start 2015-03-06T14:32:00 "
+                                   "--stop 2015-03-06T14:36:00"
+                                   ) % metric["id"])
+        measures = self.parser.listing(result)
+        self.assertEqual([{'granularity': '3600.0',
+                           'timestamp': '2015-03-06T14:00:00+00:00',
+                           'value': '27.555'}], measures)
+
         # MEASURES AGGREGATION
         result = self.gnocchi(
             'measures', params=("aggregation "
                                 "--metric %s "
                                 "--aggregation mean "
+                                "--reaggregation sum "
+                                "--granularity 1 "
                                 "--start 2015-03-06T14:32:00 "
                                 "--stop 2015-03-06T14:36:00"
                                 ) % metric["id"])
@@ -152,6 +183,17 @@ class MetricClientTest(base.ClientTestBase):
             # when LP#1497171 is fixed
             self.assertEqual(metric[field], metric_from_list[field], field)
 
+        # LIST + limit
+        result = self.gnocchi('metric',
+                              params=("list "
+                                      "--sort name:asc "
+                                      "--marker %s "
+                                      "--limit 1") % metric['id'])
+        metrics = self.parser.listing(result)
+        metric_from_list = metrics[0]
+        self.assertEqual(1, len(metrics))
+        self.assertTrue(metric['name'] < metric_from_list['name'])
+
         # DELETE
         result = self.gnocchi('metric', params="delete %s" % metric["id"])
         self.assertEqual("", result)
@@ -213,13 +255,17 @@ class MetricClientTest(base.ClientTestBase):
                                       "--measure '2015-03-06T14:34:12@12'"))
         self.assertEqual("", result)
 
-        # MEASURES GET
-        result = self.retry_gnocchi(
-            5, 'measures', params=("show metric-name -r metric-res "
-                                   "--aggregation mean "
-                                   "--start 2015-03-06T14:32:00 "
-                                   "--stop 2015-03-06T14:36:00"))
-
+        # MEASURES AGGREGATION with refresh
+        result = self.gnocchi(
+            'measures', params=("aggregation "
+                                "--query \"id='metric-res'\" "
+                                "--resource-type \"generic\" "
+                                "-m metric-name "
+                                "--aggregation mean "
+                                "--needed-overlap 0 "
+                                "--start 2015-03-06T14:32:00 "
+                                "--stop 2015-03-06T14:36:00 "
+                                "--refresh"))
         measures = self.parser.listing(result)
         self.assertEqual([{'granularity': '1.0',
                            'timestamp': '2015-03-06T14:33:57+00:00',
@@ -246,6 +292,21 @@ class MetricClientTest(base.ClientTestBase):
                            'timestamp': '2015-03-06T14:34:12+00:00',
                            'value': '12.0'}], measures)
 
+        # MEASURES AGGREGATION RESAMPLE
+        result = self.gnocchi(
+            'measures', params=("aggregation "
+                                "--query \"id='metric-res'\" "
+                                "--resource-type \"generic\" "
+                                "-m metric-name --granularity 1 "
+                                "--aggregation mean --resample=3600 "
+                                "--needed-overlap 0 "
+                                "--start 2015-03-06T14:32:00 "
+                                "--stop 2015-03-06T14:36:00"))
+        measures = self.parser.listing(result)
+        self.assertEqual([{'granularity': '3600.0',
+                           'timestamp': '2015-03-06T14:00:00+00:00',
+                           'value': '27.555'}], measures)
+
         # MEASURES AGGREGATION GROUPBY
         result = self.gnocchi(
             'measures', params=("aggregation "
@@ -268,6 +329,21 @@ class MetricClientTest(base.ClientTestBase):
                            'timestamp': '2015-03-06T14:34:12+00:00',
                            'value': '12.0'}], measures)
 
+        # MEASURES GET
+        result = self.gnocchi('measures',
+                              params=("show metric-name -r metric-res "
+                                      "--aggregation mean "
+                                      "--start 2015-03-06T14:32:00 "
+                                      "--stop 2015-03-06T14:36:00"))
+
+        measures = self.parser.listing(result)
+        self.assertEqual([{'granularity': '1.0',
+                           'timestamp': '2015-03-06T14:33:57+00:00',
+                           'value': '43.11'},
+                          {'granularity': '1.0',
+                           'timestamp': '2015-03-06T14:34:12+00:00',
+                           'value': '12.0'}], measures)
+
         # BATCHING
         measures = json.dumps({'metric-res': {'metric-name': [{
             'timestamp': '2015-03-06T14:34:12', 'value': 12
@@ -282,6 +358,14 @@ class MetricClientTest(base.ClientTestBase):
         self.gnocchi('measures', params="batch-resources-metrics -",
                      input=measures.encode('utf8'))
 
+        # BATCHING --create-metrics
+        measures = json.dumps({'metric-res': {'unknown-metric-name': [{
+            'timestamp': '2015-03-06T14:34:12', 'value': 12
+        }]}})
+        self.gnocchi('measures',
+                     params="batch-resources-metrics --create-metrics -",
+                     input=measures.encode('utf8'),)
+
         # LIST
         result = self.gnocchi('metric', params="list")
         metrics = self.parser.listing(result)
