@@ -26,11 +26,22 @@ class MetricManager(base.Manager):
     metric_batch_url = "v1/batch/metrics/measures"
     resources_batch_url = "v1/batch/resources/metrics/measures"
 
-    def list(self):
-        """List archive metrics
+    def list(self, limit=None, marker=None, sorts=None):
+        """List metrics
+
+        :param limit: maximum number of resources to return
+        :type limit: int
+        :param marker: the last item of the previous page; we return the next
+                       results after this value.
+        :type marker: str
+        :param sorts: list of resource attributes to order by. (example
+                      ["user_id:desc-nullslast", "project_id:asc"]
+        :type sorts: list of str
 
         """
-        return self._get(self.metric_url).json()
+        qs = utils.build_pagination_options(False, False, limit, marker,
+                                            sorts)
+        return self._get("%s?%s" % (self.metric_url[:-1], qs)).json()
 
     @staticmethod
     def _ensure_metric_is_uuid(metric, attribute="resource_id"):
@@ -140,7 +151,7 @@ class MetricManager(base.Manager):
             headers={'Content-Type': "application/json"},
             data=jsonutils.dumps(measures))
 
-    def batch_resources_metrics_measures(self, measures):
+    def batch_resources_metrics_measures(self, measures, create_metrics=False):
         """Add measurements to named metrics if resources
 
         :param measures: measurements
@@ -151,10 +162,12 @@ class MetricManager(base.Manager):
         return self._post(
             self.resources_batch_url,
             headers={'Content-Type': "application/json"},
-            data=jsonutils.dumps(measures))
+            data=jsonutils.dumps(measures),
+            params=dict(create_metrics=create_metrics))
 
     def get_measures(self, metric, start=None, stop=None, aggregation=None,
-                     granularity=None, resource_id=None, **kwargs):
+                     granularity=None, resource_id=None, refresh=False,
+                     resample=None, **kwargs):
         """Get measurements of a metric
 
         :param metric: ID or Name of the metric
@@ -170,6 +183,10 @@ class MetricManager(base.Manager):
         :param resource_id: ID of the resource (required
                             to get a metric by name)
         :type resource_id: str
+        :param refresh: force aggregation of all known measures
+        :type refresh: bool
+        :param resample: resample measures to new granularity
+        :type resample: float
 
         All other arguments are arguments are dedicated to custom aggregation
         method passed as-is to the Gnocchi.
@@ -181,7 +198,8 @@ class MetricManager(base.Manager):
             stop = stop.isoformat()
 
         params = dict(start=start, stop=stop, aggregation=aggregation,
-                      granularity=granularity)
+                      granularity=granularity, refresh=refresh,
+                      resample=resample)
         params.update(kwargs)
         if resource_id is None:
             self._ensure_metric_is_uuid(metric)
@@ -193,8 +211,9 @@ class MetricManager(base.Manager):
 
     def aggregation(self, metrics, query=None,
                     start=None, stop=None, aggregation=None,
-                    granularity=None, needed_overlap=None,
-                    resource_type="generic", groupby=None):
+                    reaggregation=None, granularity=None,
+                    needed_overlap=None, resource_type="generic",
+                    groupby=None, refresh=False, resample=None):
         """Get measurements of an aggregated metrics
 
         :param metrics: IDs of metric or metric name
@@ -205,8 +224,10 @@ class MetricManager(base.Manager):
         :type start: timestamp
         :param stop: end of the period
         :type stop: timestamp
-        :param aggregation: aggregation to retrieve
+        :param aggregation: granularity aggregation function to retrieve
         :type aggregation: str
+        :param reaggregation: groupby aggregation function to retrieve
+        :type reaggregation: str
         :param granularity: granularity to retrieve (in seconds)
         :type granularity: int
         :param needed_overlap: percent of datapoints in each metrics required
@@ -215,6 +236,10 @@ class MetricManager(base.Manager):
         :type resource_type: str
         :param groupby: list of attribute to group by
         :type groupby: list
+        :param refresh: force aggregation of all known measures
+        :type refresh: bool
+        :param resample: resample measures to new granularity
+        :type resample: float
 
         See Gnocchi REST API documentation for the format
         of *query dictionary*
@@ -227,8 +252,9 @@ class MetricManager(base.Manager):
             stop = stop.isoformat()
 
         params = dict(start=start, stop=stop, aggregation=aggregation,
-                      granularity=granularity, needed_overlap=needed_overlap,
-                      groupby=groupby)
+                      reaggregation=reaggregation, granularity=granularity,
+                      needed_overlap=needed_overlap, groupby=groupby,
+                      refresh=refresh, resample=resample)
         if query is None:
             for metric in metrics:
                 self._ensure_metric_is_uuid(metric)
