@@ -34,8 +34,22 @@ class CliMetricList(lister.Lister):
 
     COLS = ('id', 'archive_policy/name', 'name', 'unit', 'resource_id')
 
+    def get_parser(self, prog_name):
+        parser = super(CliMetricList, self).get_parser(prog_name)
+        parser.add_argument("--limit", type=int, metavar="<LIMIT>",
+                            help="Number of metrics to return "
+                            "(Default is server default)")
+        parser.add_argument("--marker", metavar="<MARKER>",
+                            help="Last item of the previous listing. "
+                            "Return the next results after this value")
+        parser.add_argument("--sort", action="append", metavar="<SORT>",
+                            help="Sort of metric attribute "
+                            "(example: user_id:desc-nullslast")
+        return parser
+
     def take_action(self, parsed_args):
-        metrics = utils.get_client(self).metric.list()
+        metrics = utils.get_client(self).metric.list(
+            **utils.get_pagination_options(parsed_args))
         for metric in metrics:
             utils.format_archive_policy(metric["archive_policy"])
             utils.format_move_dict_to_root(metric, "archive_policy")
@@ -132,6 +146,11 @@ class CliMeasuresShow(CliMetricWithResourceID, lister.Lister):
                             help="end of the period")
         parser.add_argument("--granularity",
                             help="granularity to retrieve (in seconds)")
+        parser.add_argument("--refresh", action="store_true",
+                            help="force aggregation of all known measures")
+        parser.add_argument("--resample",
+                            help=("granularity to resample time-series to "
+                                  "(in seconds)"))
         return parser
 
     def take_action(self, parsed_args):
@@ -142,6 +161,8 @@ class CliMeasuresShow(CliMetricWithResourceID, lister.Lister):
             start=parsed_args.start,
             stop=parsed_args.stop,
             granularity=parsed_args.granularity,
+            refresh=parsed_args.refresh,
+            resample=parsed_args.resample
         )
         return self.COLS, measures
 
@@ -199,10 +220,17 @@ class CliMetricsMeasuresBatch(CliMeasuresBatch):
 
 
 class CliResourcesMetricsMeasuresBatch(CliMeasuresBatch):
+    def get_parser(self, prog_name):
+        parser = super(CliResourcesMetricsMeasuresBatch, self).get_parser(
+            prog_name)
+        parser.add_argument("--create-metrics", action='store_true',
+                            help="Create unknown metrics"),
+        return parser
+
     def take_action(self, parsed_args):
         with parsed_args.file as f:
             utils.get_client(self).metric.batch_resources_metrics_measures(
-                json.load(f))
+                json.load(f), create_metrics=parsed_args.create_metrics)
 
 
 class CliMeasuresAggregation(lister.Lister):
@@ -214,12 +242,16 @@ class CliMeasuresAggregation(lister.Lister):
         parser = super(CliMeasuresAggregation, self).get_parser(prog_name)
         parser.add_argument("-m", "--metric", nargs='+', required=True,
                             help="metrics IDs or metric name")
-        parser.add_argument("--aggregation",
-                            help="aggregation to retrieve")
+        parser.add_argument("--aggregation", help="granularity aggregation "
+                                                  "function to retrieve")
+        parser.add_argument("--reaggregation",
+                            help="groupby aggregation function to retrieve")
         parser.add_argument("--start",
                             help="beginning of the period")
         parser.add_argument("--stop",
                             help="end of the period")
+        parser.add_argument("--granularity",
+                            help="granularity to retrieve (in seconds)")
         parser.add_argument("--needed-overlap", type=float,
                             help=("percent of datapoints in each "
                                   "metrics required"))
@@ -229,6 +261,11 @@ class CliMeasuresAggregation(lister.Lister):
         parser.add_argument("--groupby",
                             action='append',
                             help="Attribute to use to group resources"),
+        parser.add_argument("--refresh", action="store_true",
+                            help="force aggregation of all known measures")
+        parser.add_argument("--resample",
+                            help=("granularity to resample time-series to "
+                                  "(in seconds)"))
         return parser
 
     def take_action(self, parsed_args):
@@ -241,11 +278,15 @@ class CliMeasuresAggregation(lister.Lister):
             metrics=metrics,
             query=parsed_args.query,
             aggregation=parsed_args.aggregation,
+            reaggregation=parsed_args.reaggregation,
             start=parsed_args.start,
             stop=parsed_args.stop,
+            granularity=parsed_args.granularity,
             needed_overlap=parsed_args.needed_overlap,
             resource_type=parsed_args.resource_type,
             groupby=parsed_args.groupby,
+            refresh=parsed_args.refresh,
+            resample=parsed_args.resample
         )
         if parsed_args.groupby:
             ms = []
